#[non_exhaustive]pub struct RenderOptions {
pub wrap_width: Option<usize>,
pub min_wrap_width: usize,
pub allow_width_overflow: bool,
pub pad_block_width: bool,
pub raw: bool,
pub draw_borders: bool,
}Expand description
Rendering options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wrap_width: Option<usize>The maximum text wrap width. If set, paragraphs of text will only be wrapped to that width or less, though the overall width can be larger (e.g. for indented blocks or side-by-side table cells).
min_wrap_width: usizeThe minimum text width to use when wrapping.
allow_width_overflow: boolIf true, then allow the output to be wider than specified instead of returning
Err(TooNarrow).
pad_block_width: boolWhether to always pad lines out to the full width. This may give a better output when the parent block has a background colour set.
raw: boolRaw extraction, ensures text in table cells ends up rendered together This traverses tables as if they had a single column and every cell is its own row.
draw_borders: boolWhether to draw table borders